const fs = require('fs');
const https = require('https');
const privateKey  = fs.readFileSync('ssl/authapi.key', 'utf8');
const certificate = fs.readFileSync('ssl/authapi.crt', 'utf8');
const credentials = {key: privateKey, cert: certificate};
const cookieParser = require('cookie-parser');

const Config = require("./commons/config");

// read env files
const result = require('dotenv').config();
if (result.error) {
  throw result.error
}

// setup express
const express = require('express');
const bodyParser = require('body-parser');
const cors = require("cors");

const authapiRouter = require('./routes/authapi.route'); // Imports routes
const app = express();

var corsOptions = {
  origin: [ /.*$/ ],
  credentials: true,
  allowedHeaders: "x-xsrf-token, Origin, Content-Type, Accept",
};

// setup mongo connection
const mongoose = require('mongoose');
let dev_db_url = 'mongodb://localhost/authapi';
let mongoDB = process.env.MONGODB_URI || dev_db_url;
//mongoose.set('debug',true);
mongoose.connect(mongoDB);
mongoose.Promise = global.Promise;
let db = mongoose.connection;
db.on('error', console.error.bind(console, 'MongoDB connection error:'));

mongoose.set('useFindAndModify', false);
// get the Right model to initialize Rights collection if it is empty

const DbInint = require('./db.init');
DbInint.initUsers();

// define pre-processing: CORS, parsing JSON, ...
app.use(cookieParser(Config.secretKey))
app.use(cors(corsOptions));
app.use(bodyParser.json());
app.use(bodyParser.urlencoded({extended: false}));

// define routes
app.use('/authapi', authapiRouter);

/*
Uncomment the following lines in case of the production vuejs app is hosted on the same machine
that runs this API. In that case, jsut change the path to the index.html of the SPA

app.get('/', (req,res) => {
  res.sendFile(path.join(__dirname, '../../vuejs/gnose/dist/index.html'));
});
*/


// send 404 if no valid route
app.use((req,res,next) => {
  //res.sendFile(path.join(__dirname, '../../vuejs/gnose/dist/index.html'));
  res.status(404).send({err:1, status: 404, data: 'route d\'accès à l\'API invalide'})
})

// send 500 in case of an error
app.use((err, req, res, next) => {
  console.log(JSON.stringify(err));
  if (err.status === undefined) {
    res.status(500).send({err:2, status: 500, data: 'Erreur interne de \'API'})
  }
  else {
    res.status(err.status).send(err)
  }
});


// start server
var httpsServer = https.createServer(credentials, app);
httpsServer.listen(process.env.PORT, () =>
  console.log(`authapi started on port ${process.env.PORT}!`)
);




