const Config = require('./config');

const ERR_AUTH_LOGIN_NOT_DEFINED = 600;
const ERR_AUTH_PASSWORD_NOT_DEFINED = 601;

const ERR_AUTH_NO_TOKEN = 620;
const ERR_AUTH_NOT_AUTHORIZED = 621;
const ERR_AUTH_TOKEN_EXPIRED = 622;
const ERR_AUTH_PASSWORD_NO_MATCH = 629;


const userErrors = [
  { number: ERR_AUTH_LOGIN_NOT_DEFINED, status: 400, message: { en: 'user\'s login is not defined or invalid', fr: 'le login de l\'utilisateur n\'est pas défini ou invalide' }},
  { number: ERR_AUTH_PASSWORD_NOT_DEFINED, status: 400, message: { en: 'user\'s password is not defined or invalid', fr: 'le mot de passe de l\'utilisateur n\'est pas défini ou invalide' }},
  { number: ERR_AUTH_NO_TOKEN, status: 400, message: { en: 'no provided jwt token', fr: 'aucun token jwt n\'est fourni' }},
  { number: ERR_AUTH_NOT_AUTHORIZED, status: 401, message: { en: 'invalid jwt token: unauthorized', fr: 'token jwt invalide: autorisation refusée' }},
  { number: ERR_AUTH_TOKEN_EXPIRED, status: 401, message: { en: 'unauthorized: token expired', fr: 'le token jwt fourni a expiré' }},
  { number: ERR_AUTH_PASSWORD_NO_MATCH, status: 401, message: { en: 'given password is invalid', fr: 'le mot de passe fourni est invalide' }},
];

const getError = (number, lang) => {
  if (lang === undefined) lang = Config.defaultLang;
  let err = userErrors.find(e => e.number === number);
  if (err !== undefined) {
    if (lang === 'en') {
      return {
        error: err.number,
        status: err.status,
        data: err.message.en
      };
    }
    else if (lang === 'fr') {
      return {
        error: err.number,
        status: err.status,
        data: err.message.fr
    };
    }
  }
  return {
    err: 1,
    data: 'undetermined error'
  }
};

module.exports = {
  ERR_AUTH_LOGIN_NOT_DEFINED,
  ERR_AUTH_PASSWORD_NOT_DEFINED,
  ERR_AUTH_NO_TOKEN,
  ERR_AUTH_NOT_AUTHORIZED,
  ERR_AUTH_TOKEN_EXPIRED,
  ERR_AUTH_PASSWORD_NO_MATCH,
  getError
};


