const Config = require('./config');

const ERR_USER_INVALID_FIND_LOGIN_REQUEST = 427;
const ERR_USER_CANNOT_FIND_LOGIN = 428;
const ERR_USER_INVALID_FIND_USERS_REQUEST = 433;
const ERR_USER_INVALID_FIND_USER_REQUEST = 434;

const userErrors = [
  { number: ERR_USER_INVALID_FIND_LOGIN_REQUEST, status: 400, message: { en: 'invalid find user by login request', fr: 'requête de recherche d\'un utilisateur par login invalide' }},
  { number: ERR_USER_CANNOT_FIND_LOGIN, status: 404, message: { en: 'cannot find a user with the given login', fr: 'impossible de trouver un utilisateur avec le login indiqué' }},
  { number: ERR_USER_INVALID_FIND_USERS_REQUEST, status: 400, message: { en: 'invalid request to get all users', fr: 'requête pour récupérer les utilisateurs invalide' }},
  { number: ERR_USER_INVALID_FIND_USER_REQUEST, status: 400, message: { en: 'invalid request to get one user', fr: 'requête invalide pour récupérer un utilisateur' }},
];

const getError = (number, lang) => {
  if (lang === undefined) lang = Config.defaultLang;
  let err = userErrors.find(e => e.number === number);
  if (err !== undefined) {
    if (lang === 'en') {
      return {
        error: err.number,
        status: err.status,
        data: err.message.en
      };
    }
    else if (lang === 'fr') {
      return {
        error: err.number,
        status: err.status,
        data: err.message.fr
    };
    }
  }
  return {
    err: 1,
    data: 'undetermined error'
  }
};

module.exports = {
  ERR_USER_INVALID_FIND_LOGIN_REQUEST,
  ERR_USER_CANNOT_FIND_LOGIN,
  ERR_USER_INVALID_FIND_USERS_REQUEST,
  ERR_USER_INVALID_FIND_USER_REQUEST,
  getError
};


