const User = require('../models/user.model');
const UserErrors = require('../commons/userErrors');

const {answer} = require('./ControllerAnswer')

/**
 * get all users
 * @param {Object} req - The request object (provided by express)
 * @param {Object} res - The result object used to send the result to the client (provided by express)
 * @param {Function} next - The next middleware to call after this one
 */
const getUsers = async function (req, res, next) {
  answer.reset()
  console.log('get users');
  try {
    users = await User.find({}, '_id login').exec();
  }
  catch(err) {
    answer.set(UserErrors.getError(UserErrors.ERR_USER_INVALID_FIND_USERS_REQUEST))
    return next(answer);
  }
  // sends back all users
  answer.setPayload(users)
  res.status(200).send(answer);
};

/**
 * get an user with its login
 * @param {Object} req - The request object (provided by express)
 * @param {Object} res - The result object used to send the result to the client (provided by express)
 * @param {Function} next - The next middleware to call after this one
 */
const getUser = async function (req, res, next) {
  answer.reset()
  console.log('get user by login');
  let user = null
  try {
    user = await User.find({login: req.params.login}).exec();
  }
  catch(err) {
    answer.set(UserErrors.getError(UserErrors.ERR_USER_INVALID_FIND_USER_REQUEST))
    return next(answer);
  }
  // if none is found => error
  if ((user.length) && (user.length !== 1)) {
    answer.set(UserErrors.getError(UserErrors.ERR_USER_INVALID_FIND_USER_REQUEST))
    return next(answer);
  }
  // sends back all users
  answer.setPayload( user[0])
  res.status(200).send(answer)
};


module.exports = {
  getUsers,
  getUser
};
